/*
                       Endeavour Recycle Bin Sync

	Compacts the recycled objects and fixes errors in the Recycle
	Bin.
 */

#ifndef EDVRECBINSYNC_H
#define EDVRECBINSYNC_H

#include <gtk/gtk.h>

#include "edvtypes.h"
#include "edvrecbin.h"
#include "endeavour.h"


extern gint EDVRecBinSync(
	edv_core_struct *core_ptr,
	GtkWidget *toplevel,
	gboolean show_progress, gboolean interactive,
	gboolean *yes_to_all,
	void (*status_message_cb)(
		const gchar *,		/* Message */
		gpointer		/* Data */
	),
	void (*status_progress_cb)(
		gfloat,			/* Progress */
		gpointer		/* Data */
	),
	gpointer data
);


#endif	/* EDVRECBINSYNC_H */
